<p align="center" style="">
    <img src="./doc/momos_header.svg"/>
</p>

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![PyPI version](https://badge.fury.io/py/momos.svg)](https://badge.fury.io/py/momos)
![CI Test](https://github.com/codetent/project_momos/actions/workflows/python-package.yml/badge.svg)

# Project Momos

## Introduction

`Momos` = son of greek goddess Nyx, who was known for his sharp-tongued criticism

This project is an experimental approach for creating a tool for testing state machine based protocol implementations against the specification for uncovering structural issues.

The tool is not limited by design to any programming language or testing framework but currently only integrates well with cmake and C/C++.
